/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrltur.parameter;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Beschreibt aktuell von der Zählmethode gefundenen Fahrzeuge, und zwar sowohl die
				identifizierten als auch die nicht identifizierten, die z.B. durch den Korrekturwert
				bestimmt werden. Die Attributgruppe ist parametrierend, damit die Informationen über einen
				Neustart der SWE persistiert werden.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class PdTurVorhandeneFahrzeuge extends AbstractParameterDatensatz<PdTurVorhandeneFahrzeuge.Daten> {

		/**
		 * Die vorhandenen Aspekte des Datensatzes.
		 */
		public static class Aspekte extends de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.objekte.impl.AspektImpl implements Aspekt {
	
			public static Aspekt[] values() {
				return new Aspekt[] {
					Aspekte.ParameterDefault,
					Aspekte.ParameterSoll,
					Aspekte.ParameterVorgabe,
					Aspekte.ParameterIst,
				};
			}
	
			/**
			 * Aspekt der zur Versorgung von Defaultwerten für Parameter verwendet werden kann.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterDefault = new Aspekte("Default-Parameter-Aspekt", "asp.parameterDefault");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterSoll = new Aspekte("Soll-Parameter-Aspekt", "asp.parameterSoll");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterVorgabe = new Aspekte("Vorgabe-Parameter-Aspekt", "asp.parameterVorgabe");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterIst = new Aspekte("Ist-Parameter-Aspekt", "asp.parameterIst");
			
			;
			
			private final String name;
			private final String pid;
	
			private Aspekte(final String name, final String pid) {
				this.name = name;
				this.pid = pid;
			}
	
			@Override
			public String getName() {
				if (getSystemObject() == null) {
					return name;
				}
				return super.getName();
			}
	
			@Override
			public String getPid() {
				if (getSystemObject() == null) {
					return pid;
				}
				return super.getPid();
			}
			
			@Override
			public Aspect getSystemObject() {
				return (Aspect) super.getSystemObject();
			}
	
			@Override
			public String toString() {
				if (getSystemObject() == null) {
					return name + " (" + pid + ")";
				}
				return super.toString();
			}
	
		}
	
	/**
	 * Kapselt die Daten des Datensatzes.
	 */
	public static class Daten extends AbstractOnlineDatum {
		
		/**
		 * Initialisiert das Onlinedatum.
		 * 
		 * @param datensatz
		 *            der Datensatz zu dem das Datum gehört.
		 * @param aspekt
		 *            der Aspekt für das Datum.
		 */
		public Daten(final Datensatz datensatz, final Aspekt aspekt) {
			super(datensatz, aspekt);
		}
		
		
			/*
			 * Beginn Propertiesabschnitt
			 */
		
				private de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 _urlasser
				= new de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				()
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.bitctrlbasic.attribute.AttZahlPositiv16Bit
				 _anzahlNichtIdentifizierterFz
				;
				private 	Zeitstempel
				 _zeitstempelNichtIdentifizierterFz
				;
				private Feld<de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttZahlPositiv
				> _identifizierteFz = new Feld<de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttZahlPositiv
				>(0, true);
		
			/**
			Urlasserinformationen.
			<p>
			Urlasserinformationen bestehen aus einer Referenz auf den Benutzer, der die Meldung erzeugt hat, einer Angabe der Ursache für die Meldung und einem Veranlasser für die Meldung.
			</p>
			
			@return der Wert von Urlasser.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 getUrlasser() {
				return _urlasser;
			}
		
			/**
			Urlasserinformationen.
			<p>
			Urlasserinformationen bestehen aus einer Referenz auf den Benutzer, der die Meldung erzeugt hat, einer Angabe der Ursache für die Meldung und einem Veranlasser für die Meldung.
			</p>
			
			@param _urlasser der neue Wert von Urlasser.
			*/
			public void setUrlasser(de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
			 _urlasser) {
				this._urlasser = _urlasser;
			}
		
			/**
			Positive ganze Zahl mit 16 Bits, also im Bereich 0 bis
								65535.
			<p>
			
			</p>
			
			@return der Wert von AnzahlNichtIdentifizierterFz.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.bitctrlbasic.attribute.AttZahlPositiv16Bit
				 getAnzahlNichtIdentifizierterFz() {
				return _anzahlNichtIdentifizierterFz;
			}
		
			/**
			Positive ganze Zahl mit 16 Bits, also im Bereich 0 bis
								65535.
			<p>
			
			</p>
			
			@param _anzahlNichtIdentifizierterFz der neue Wert von AnzahlNichtIdentifizierterFz.
			*/
			public void setAnzahlNichtIdentifizierterFz(de.bsvrz.sys.funclib.bitctrl.modell.bitctrlbasic.attribute.AttZahlPositiv16Bit
			 _anzahlNichtIdentifizierterFz) {
				this._anzahlNichtIdentifizierterFz = _anzahlNichtIdentifizierterFz;
			}
		
			/**
			Angabe eines Zeitpunktes.
			<p>
			
			</p>
			
			@return der Wert von ZeitstempelNichtIdentifizierterFz.
			*/
				public 	Zeitstempel
				 getZeitstempelNichtIdentifizierterFz() {
				return _zeitstempelNichtIdentifizierterFz;
			}
		
			/**
			Angabe eines Zeitpunktes.
			<p>
			
			</p>
			
			@param _zeitstempelNichtIdentifizierterFz der neue Wert von ZeitstempelNichtIdentifizierterFz.
			*/
			public void setZeitstempelNichtIdentifizierterFz(	Zeitstempel
			 _zeitstempelNichtIdentifizierterFz) {
				this._zeitstempelNichtIdentifizierterFz = _zeitstempelNichtIdentifizierterFz;
			}
		
			/**
			Positive ganze Zahl.
			<p>
			
			</p>
			
			@return der Wert von IdentifizierteFz.
			*/
				public Feld<de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttZahlPositiv
				> getIdentifizierteFz() {
				return _identifizierteFz;
			}
		
		
		
			/*
			 * Ende Propertiesabschnitt
			 */
		
			/*
			 * Beginn Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			public void bean2Atl(final Data datum, final ObjektFactory factory) {
					// AttributListenDefinition
						getUrlasser().bean2Atl(datum.getItem("Urlasser"), factory);
					// GanzzahlAttributTyp
					if (getAnzahlNichtIdentifizierterFz() != null) {
		                if (getAnzahlNichtIdentifizierterFz().isZustand()) {
		                    datum.getUnscaledValue("AnzahlNichtIdentifizierterFz").setText(getAnzahlNichtIdentifizierterFz().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("AnzahlNichtIdentifizierterFz").set(getAnzahlNichtIdentifizierterFz().getValue());
		                }
					}
					// ZeitstempelAttributTyp
						datum.getTimeValue("ZeitstempelNichtIdentifizierterFz").setMillis(getZeitstempelNichtIdentifizierterFz().getTime());
					// GanzzahlAttributTyp
					if (getIdentifizierteFz() != null) {
						final Data.NumberArray arrayIdentifizierteFz = datum.
							getUnscaledArray
							("IdentifizierteFz");
						arrayIdentifizierteFz.setLength(getIdentifizierteFz().size());
						for (int i = 0; i < arrayIdentifizierteFz.getLength(); ++i) {
							arrayIdentifizierteFz.getValue(i).set(getIdentifizierteFz().get(i).getValue());
						}
					}
			}
		
			public void atl2Bean(final Data daten, final ObjektFactory factory) {
					// AttributListenDefinition
						getUrlasser().atl2Bean(daten.getItem("Urlasser"), factory);
					// GanzzahlAttributTyp
							setAnzahlNichtIdentifizierterFz(new de.bsvrz.sys.funclib.bitctrl.modell.bitctrlbasic.attribute.AttZahlPositiv16Bit
							(daten.
								getUnscaledValue
							("AnzahlNichtIdentifizierterFz").
									intValue
							()));
					// ZeitstempelAttributTyp
						setZeitstempelNichtIdentifizierterFz(new
							Zeitstempel
							(daten.getTimeValue("ZeitstempelNichtIdentifizierterFz").getMillis()));
					// GanzzahlAttributTyp
						final Data.NumberArray arrayIdentifizierteFz = daten.
							getUnscaledArray
						("IdentifizierteFz");
		
						for (int i = 0; i < arrayIdentifizierteFz.getLength(); ++i) {
		                    getIdentifizierteFz().add(new de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttZahlPositiv
		                    (arrayIdentifizierteFz.
		                    		longValue
		                    (i)));
		                }
			}
		
			/*
			 * Ende Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			
		@Override
		public Daten clone() {
			final Daten klon = new Daten(dGetDatensatz(), dGetAspekt());
	
							klon._urlasser = getUrlasser().clone();
							klon.setAnzahlNichtIdentifizierterFz(getAnzahlNichtIdentifizierterFz());
							klon.setZeitstempelNichtIdentifizierterFz(getZeitstempelNichtIdentifizierterFz());
						klon._identifizierteFz = getIdentifizierteFz().clone();
			
			
			klon.dSetZeitstempel(dGetZeitstempel());
			klon.dSetDatenStatus(dGetDatenStatus());
	
			return klon;
		}

		@Override
		public String toString() {
			return BeanUtils.toString(this);
		}
	
	}

		/** Die PID der Attributgruppe im Datenverteiler. */
		public static final String PID = "atg.turVorhandeneFahrzeuge";

	/**
	 * Initialisiert den Parameterdatensatz.
	 * 
	 * @param systemObjekt
	 *            das Systemobjekt zu dem der Datensatz gehört.
	 * @param objektFactory
	 *            die ObjektFabrik, die der Datensatz verwenden soll.
	 */
	public PdTurVorhandeneFahrzeuge(final SystemObjekt systemObjekt,
			final ObjektFactory objektFactory) {
		super(systemObjekt, objektFactory);
	}

	
		@Override
		public void init(final SystemObject systemObject,
				final ObjektFactory objektFactory) {
			super.init(systemObject, objektFactory);
			for (final Aspekt asp : Aspekte.values()) {
				((AbstractSystemObjekt) asp).init(objektFactory.getModellobjekt(asp.getPid()).getSystemObject(), objektFactory);
			}
		}
		
		@Override
		protected String doGetPid() {
			return PID;
		}
	
		public Collection<? extends Aspekt> getAspekte() {
			return Arrays.asList(Aspekte.values());
		}
	
		public Daten createDatum() {
			Daten datum = new Daten(this, null);
			// TODO Auslesen der Defaultwerte geht nicht,
			// weil der Datenverteiler für Attribute ohne Defaultwert initial ungültige Werte setzt!!
			// datum.atl2Bean(createSendeCache(), getObjektFactory());
			return datum;
		}
		 

}
