/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Art der Übertragung (nach Abruf &#47; zyklisch &#47; nach
					Änderung).
<p>
&lt;absatz&gt;
						Gibt an, wann die Daten der Messwertgeber zur
						Zentrale übertragen werden: Entweder auf Abruf
						durch die Zentrale (Ereignisklasse 2), oder nach
						Zustandsänderungen (Ereignisklasse 1).Optional
						können die Daten auch spontan nach Ende der o.g.
						Erfassungsperiode (Ereignisklasse 1) übertragen
						werden. Meldung nur nach Abruf durch die
						Zentrale bedeutet, dass der DE ohne Aufforderung
						keine Meldungen mehr abgibt. Das
						Standardübertragungsverfahren in der FG 6 ist
						die spontane Meldung nach Zustandsänderungen.
					&lt;&#47;absatz&gt;
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttTlsVltUebertragungsverfahren extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsVltUebertragungsverfahren ZUSTAND_0_MELDUNG_NUR_NACH_ABRUF = new AttTlsVltUebertragungsverfahren("Meldung nur nach Abruf", 		Byte
	.valueOf("0"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsVltUebertragungsverfahren ZUSTAND_1_ZYKLISCHE_ABGABE_VON_MELDUNGEN = new AttTlsVltUebertragungsverfahren("Zyklische Abgabe von Meldungen", 		Byte
	.valueOf("1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsVltUebertragungsverfahren ZUSTAND_2_NACH_ZUSTANDAENDERUNG = new AttTlsVltUebertragungsverfahren("nach Zustandänderung", 		Byte
	.valueOf("2"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsVltUebertragungsverfahren getZustand(final 		Byte
	 value) {
		for (AttTlsVltUebertragungsverfahren e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsVltUebertragungsverfahren getZustand(final String value) {
		for (AttTlsVltUebertragungsverfahren e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsVltUebertragungsverfahren> getZustaende() {
		List<AttTlsVltUebertragungsverfahren> list = new ArrayList<AttTlsVltUebertragungsverfahren>();
		list.add(ZUSTAND_0_MELDUNG_NUR_NACH_ABRUF);
		list.add(ZUSTAND_1_ZYKLISCHE_ABGABE_VON_MELDUNGEN);
		list.add(ZUSTAND_2_NACH_ZUSTANDAENDERUNG);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TLSVltÜbertragungsverfahren.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsVltUebertragungsverfahren(final 		Byte
	 value) {
		super(value);
	}
	
	private AttTlsVltUebertragungsverfahren(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
