/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.parameter;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Codedefinition (FG 4 &#47; Typ 44) (FG 4 &#47; Typ 44).
<p>
&lt;sektion&gt;
						&lt;titel&gt;
							FG 4: DE-Block-Struktur im Typ 44
							?Codedefinition?
						&lt;&#47;titel&gt;
						&lt;absatz&gt;
							Die Nachricht wird verwendet mit ID 3
							(Parameter) in Abruf- und Antwortrichtung.
							Die Nachricht wird abweichend von anderen
							Parameternachrichten zusammen mit dem
							Zeitstempel Typ 31 gesendet. Als
							Abruftelegramm mit ID 19 ist das Telegramm
							nicht zulässig und wird mit Code 1
							?unbekannte oder nicht auswertbare ID?
							negativ quittiert, da der zu erfragende
							Stellcode nicht übermittelt werden kann. Die
							Abfragefunktionalität wird durch den
							DE-Block Typ 21 zur Verfügung gestellt.
						&lt;&#47;absatz&gt;
						&lt;absatz&gt;
							Die Nachricht überträgt für Wzgs und
							Clusterkanäle die vor Ort ausfallsicher
							abgelegten Definitionen der Stellcodes. Wenn
							ein EAK oder ein DE einen noch nicht in
							seiner Liste vorhandenen Stellcode empfängt
							und noch freier Speicher vorhanden ist, wird
							dieser Stellcode und seine Definition
							gespeichert. Ein Block, der keine
							Komponentendefinitionen enthält, sondern nur
							einen Stellcode, dient zum Löschen der
							Definition des entsprechenden Stellcodes aus
							dem Speicher. Diese Eigenschaften sind
							optional und führen bei Nichtimplementierung
							zu einer negativen Quittung mit Code 41
							?Stellcodevorrat nicht änderbar?. Ist der
							Stellcode bereits definiert, überschreibt
							die empfangene Nachricht die alte
							Definition. Auch diese Eigenschaft ist
							optional. Bei Nichtimplementierung wird in
							der negativen Quittung der Code 42
							?Stellcodedefinition nicht änderbar?
							verwendet.
						&lt;&#47;absatz&gt;
						&lt;absatz&gt;
							Wird durch Neudefinition oder Löschen der
							Stellcodevorrat eines DEs oder EAKs
							verändert, so sendet dieser zusätzlich zur
							Rückmeldung der Definition spontan (d.h.
							insbesondere in einem separaten
							Einzeltelegramm) eine Nachricht vom Typ 43
							?Codeliste? mit dem neuen Stellcodevorrat.
						&lt;&#47;absatz&gt;
					&lt;&#47;sektion&gt;
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 5
 */
public class PdTlsWzgCodeDefinition extends AbstractParameterDatensatz<PdTlsWzgCodeDefinition.Daten> {

		/**
		 * Die vorhandenen Aspekte des Datensatzes.
		 */
		public static class Aspekte extends de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.objekte.impl.AspektImpl implements Aspekt {
	
			public static Aspekt[] values() {
				return new Aspekt[] {
					Aspekte.TlsParameterVorgabeArchiv,
					Aspekte.ParameterDefault,
					Aspekte.ParameterSoll,
					Aspekte.ParameterVorgabe,
					Aspekte.ParameterIst,
				};
			}
	
			/**
			 * Aspekt für den Quittierungsmechanismus des Archivs. Wird alternativ zu asp.parameterVorgabe
						verwendet, wenn die Vorgabe indirekt nach der Archivierung durch das Archiv
						erfolgen soll.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt TlsParameterVorgabeArchiv = new Aspekte("TlsVorgabeArchiv", "asp.tlsParameterVorgabeArchiv");
			
			/**
			 * Aspekt der zur Versorgung von Defaultwerten für Parameter verwendet werden kann.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterDefault = new Aspekte("Default-Parameter-Aspekt", "asp.parameterDefault");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterSoll = new Aspekte("Soll-Parameter-Aspekt", "asp.parameterSoll");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterVorgabe = new Aspekte("Vorgabe-Parameter-Aspekt", "asp.parameterVorgabe");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterIst = new Aspekte("Ist-Parameter-Aspekt", "asp.parameterIst");
			
			;
			
			private final String name;
			private final String pid;
	
			private Aspekte(final String name, final String pid) {
				this.name = name;
				this.pid = pid;
			}
	
			@Override
			public String getName() {
				if (getSystemObject() == null) {
					return name;
				}
				return super.getName();
			}
	
			@Override
			public String getPid() {
				if (getSystemObject() == null) {
					return pid;
				}
				return super.getPid();
			}
			
			@Override
			public Aspect getSystemObject() {
				return (Aspect) super.getSystemObject();
			}
	
			@Override
			public String toString() {
				if (getSystemObject() == null) {
					return name + " (" + pid + ")";
				}
				return super.toString();
			}
	
		}
	
	/**
	 * Kapselt die Daten des Datensatzes.
	 */
	public static class Daten extends AbstractOnlineDatum {
		
		/**
		 * Initialisiert das Onlinedatum.
		 * 
		 * @param datensatz
		 *            der Datensatz zu dem das Datum gehört.
		 * @param aspekt
		 *            der Aspekt für das Datum.
		 */
		public Daten(final Datensatz datensatz, final Aspekt aspekt) {
			super(datensatz, aspekt);
		}
		
		
			/*
			 * Beginn Propertiesabschnitt
			 */
		
				private de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 _urlasser
				= new de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				()
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgAnzeigePrinzip
				 _anzeigePrinzip
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgStellCodeDefinition
				 _stellCode
				;
				private Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzLampenDefinition
				> _lampenDefinition = new Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzLampenDefinition
				>(852, true);
				private Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzTextDefinition
				> _textDefinition = new Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzTextDefinition
				>(213, true);
				private Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzAnzeige
				> _gruppenDefinition = new Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzAnzeige
				>(106, true);
				private Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzClusterDefinition
				> _clusterDefinition = new Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzClusterDefinition
				>(53, true);
		
			/**
			Urlasserinformationen.
			<p>
			Urlasserinformationen bestehen aus einer Referenz auf den Benutzer, der die Meldung erzeugt hat, einer Angabe der Ursache für die Meldung und einem Veranlasser für die Meldung.
			</p>
			
			@return der Wert von Urlasser.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 getUrlasser() {
				return _urlasser;
			}
		
			/**
			Urlasserinformationen.
			<p>
			Urlasserinformationen bestehen aus einer Referenz auf den Benutzer, der die Meldung erzeugt hat, einer Angabe der Ursache für die Meldung und einem Veranlasser für die Meldung.
			</p>
			
			@param _urlasser der neue Wert von Urlasser.
			*/
			public void setUrlasser(de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
			 _urlasser) {
				this._urlasser = _urlasser;
			}
		
			/**
			Anzeigeprinzip des WZG entsprechend TLS.
			<p>
			
			</p>
			
			@return der Wert von AnzeigePrinzip.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgAnzeigePrinzip
				 getAnzeigePrinzip() {
				return _anzeigePrinzip;
			}
		
			/**
			Anzeigeprinzip des WZG entsprechend TLS.
			<p>
			
			</p>
			
			@param _anzeigePrinzip der neue Wert von AnzeigePrinzip.
			*/
			public void setAnzeigePrinzip(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgAnzeigePrinzip
			 _anzeigePrinzip) {
				this._anzeigePrinzip = _anzeigePrinzip;
			}
		
			/**
			Stellcode für Codelistendefinitionen.
			<p>
			
			</p>
			
			@return der Wert von StellCode.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgStellCodeDefinition
				 getStellCode() {
				return _stellCode;
			}
		
			/**
			Stellcode für Codelistendefinitionen.
			<p>
			
			</p>
			
			@param _stellCode der neue Wert von StellCode.
			*/
			public void setStellCode(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgStellCodeDefinition
			 _stellCode) {
				this._stellCode = _stellCode;
			}
		
			/**
			Lampenzuordnung bei Anzeigeprinzig B.
			<p>
			
			</p>
			
			@return der Wert von LampenDefinition.
			*/
				public Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzLampenDefinition
				> getLampenDefinition() {
				return _lampenDefinition;
			}
		
		
			/**
			Wechseltextdefiniton bei Anzeigeprinzig C und D.
			<p>
			
			</p>
			
			@return der Wert von TextDefinition.
			*/
				public Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzTextDefinition
				> getTextDefinition() {
				return _textDefinition;
			}
		
		
			/**
			WVZ-Anzeigendefinition bei Anzeigeprinzip E.
			<p>
			
			</p>
			
			@return der Wert von GruppenDefinition.
			*/
				public Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzAnzeige
				> getGruppenDefinition() {
				return _gruppenDefinition;
			}
		
		
			/**
			Komponentendefiniton an Clustern.
			<p>
			
			</p>
			
			@return der Wert von ClusterDefinition.
			*/
				public Feld<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzClusterDefinition
				> getClusterDefinition() {
				return _clusterDefinition;
			}
		
		
		
			/*
			 * Ende Propertiesabschnitt
			 */
		
			/*
			 * Beginn Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			public void bean2Atl(final Data datum, final ObjektFactory factory) {
					// AttributListenDefinition
						getUrlasser().bean2Atl(datum.getItem("Urlasser"), factory);
					// GanzzahlAttributTyp
					if (getAnzeigePrinzip() != null) {
		                if (getAnzeigePrinzip().isZustand()) {
		                    datum.getUnscaledValue("AnzeigePrinzip").setText(getAnzeigePrinzip().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("AnzeigePrinzip").set(getAnzeigePrinzip().getValue());
		                }
					}
					// GanzzahlAttributTyp
					if (getStellCode() != null) {
		                if (getStellCode().isZustand()) {
		                    datum.getUnscaledValue("StellCode").setText(getStellCode().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("StellCode").set(getStellCode().getValue());
		                }
					}
					// AttributListenDefinition
						final Data.Array arrayLampenDefinition = datum.getArray("LampenDefinition");
						arrayLampenDefinition.setLength(getLampenDefinition().size());
						for (int i = 0; i < arrayLampenDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzLampenDefinition
							 atl = getLampenDefinition().get(i);
							atl.bean2Atl(arrayLampenDefinition.getItem(i), factory);
		
						}
					// AttributListenDefinition
						final Data.Array arrayTextDefinition = datum.getArray("TextDefinition");
						arrayTextDefinition.setLength(getTextDefinition().size());
						for (int i = 0; i < arrayTextDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzTextDefinition
							 atl = getTextDefinition().get(i);
							atl.bean2Atl(arrayTextDefinition.getItem(i), factory);
		
						}
					// AttributListenDefinition
						final Data.Array arrayGruppenDefinition = datum.getArray("GruppenDefinition");
						arrayGruppenDefinition.setLength(getGruppenDefinition().size());
						for (int i = 0; i < arrayGruppenDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzAnzeige
							 atl = getGruppenDefinition().get(i);
							atl.bean2Atl(arrayGruppenDefinition.getItem(i), factory);
		
						}
					// AttributListenDefinition
						final Data.Array arrayClusterDefinition = datum.getArray("ClusterDefinition");
						arrayClusterDefinition.setLength(getClusterDefinition().size());
						for (int i = 0; i < arrayClusterDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzClusterDefinition
							 atl = getClusterDefinition().get(i);
							atl.bean2Atl(arrayClusterDefinition.getItem(i), factory);
		
						}
			}
		
			public void atl2Bean(final Data daten, final ObjektFactory factory) {
					// AttributListenDefinition
						getUrlasser().atl2Bean(daten.getItem("Urlasser"), factory);
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("AnzeigePrinzip").isState()) {
								setAnzeigePrinzip(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgAnzeigePrinzip
								.getZustand(daten.getScaledValue("AnzeigePrinzip").getText()));
							} else {
							setAnzeigePrinzip(new de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgAnzeigePrinzip
							(daten.
								getUnscaledValue
							("AnzeigePrinzip").
									byteValue
							()));
							}
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("StellCode").isState()) {
								setStellCode(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgStellCodeDefinition
								.getZustand(daten.getScaledValue("StellCode").getText()));
							} else {
							setStellCode(new de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AttTlsWzgStellCodeDefinition
							(daten.
								getUnscaledValue
							("StellCode").
									shortValue
							()));
							}
					// AttributListenDefinition
						final Data.Array arrayLampenDefinition = daten.getArray("LampenDefinition");
						for (int i = 0; i < arrayLampenDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzLampenDefinition
							 atl = new de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzLampenDefinition
							 ();
							atl.atl2Bean(arrayLampenDefinition.getItem(i), factory);
							getLampenDefinition().add(atl);
						}
					// AttributListenDefinition
						final Data.Array arrayTextDefinition = daten.getArray("TextDefinition");
						for (int i = 0; i < arrayTextDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzTextDefinition
							 atl = new de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzTextDefinition
							 ();
							atl.atl2Bean(arrayTextDefinition.getItem(i), factory);
							getTextDefinition().add(atl);
						}
					// AttributListenDefinition
						final Data.Array arrayGruppenDefinition = daten.getArray("GruppenDefinition");
						for (int i = 0; i < arrayGruppenDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzAnzeige
							 atl = new de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzAnzeige
							 ();
							atl.atl2Bean(arrayGruppenDefinition.getItem(i), factory);
							getGruppenDefinition().add(atl);
						}
					// AttributListenDefinition
						final Data.Array arrayClusterDefinition = daten.getArray("ClusterDefinition");
						for (int i = 0; i < arrayClusterDefinition.getLength(); ++i) {
							de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzClusterDefinition
							 atl = new de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute.AtlTlsWzgWvzClusterDefinition
							 ();
							atl.atl2Bean(arrayClusterDefinition.getItem(i), factory);
							getClusterDefinition().add(atl);
						}
			}
		
			/*
			 * Ende Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			
		@Override
		public Daten clone() {
			final Daten klon = new Daten(dGetDatensatz(), dGetAspekt());
	
							klon._urlasser = getUrlasser().clone();
							klon.setAnzeigePrinzip(getAnzeigePrinzip());
							klon.setStellCode(getStellCode());
						klon._lampenDefinition = getLampenDefinition().clone();
						klon._textDefinition = getTextDefinition().clone();
						klon._gruppenDefinition = getGruppenDefinition().clone();
						klon._clusterDefinition = getClusterDefinition().clone();
			
			
			klon.dSetZeitstempel(dGetZeitstempel());
			klon.dSetDatenStatus(dGetDatenStatus());
	
			return klon;
		}

		@Override
		public String toString() {
			return BeanUtils.toString(this);
		}
	
	}

		/** Die PID der Attributgruppe im Datenverteiler. */
		public static final String PID = "atg.tlsWzgCodeDefinition";

	/**
	 * Initialisiert den Parameterdatensatz.
	 * 
	 * @param systemObjekt
	 *            das Systemobjekt zu dem der Datensatz gehört.
	 * @param objektFactory
	 *            die ObjektFabrik, die der Datensatz verwenden soll.
	 */
	public PdTlsWzgCodeDefinition(final SystemObjekt systemObjekt,
			final ObjektFactory objektFactory) {
		super(systemObjekt, objektFactory);
	}

	
		@Override
		public void init(final SystemObject systemObject,
				final ObjektFactory objektFactory) {
			super.init(systemObject, objektFactory);
			for (final Aspekt asp : Aspekte.values()) {
				((AbstractSystemObjekt) asp).init(objektFactory.getModellobjekt(asp.getPid()).getSystemObject(), objektFactory);
			}
		}
		
		@Override
		protected String doGetPid() {
			return PID;
		}
	
		public Collection<? extends Aspekt> getAspekte() {
			return Arrays.asList(Aspekte.values());
		}
	
		public Daten createDatum() {
			Daten datum = new Daten(this, null);
			// TODO Auslesen der Defaultwerte geht nicht,
			// weil der Datenverteiler für Attribute ohne Defaultwert initial ungültige Werte setzt!!
			// datum.atl2Bean(createSendeCache(), getObjektFactory());
			return datum;
		}
		 

}
