/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.ilse.konfigurationsdaten;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Attributgruppe zum Steuern der externen IO.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class KdSteuerungExterneIO extends AbstractKonfigurationsDatensatz<KdSteuerungExterneIO.Daten> {

		/**
		 * Die vorhandenen Aspekte des Datensatzes.
		 */
		public static class Aspekte extends de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.objekte.impl.AspektImpl implements Aspekt {
	
			public static Aspekt[] values() {
				return new Aspekt[] {
					Aspekte.Vorgabe,
					Aspekte.Eigenschaften,
				};
			}
	
			/**
			 * Vorgabe für eine Zustandsänderung.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt Vorgabe = new Aspekte("Vorgabe", "asp.vorgabe");
			
			/**
			 * Wird für konfigurierende Attributgruppen verwendet. Über die entsprechende Attributgruppe werden die konkreten Eigenschaften eines Objekts festgelegt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt Eigenschaften = new Aspekte("Eigenschaften", "asp.eigenschaften");
			
			;
			
			private final String name;
			private final String pid;
	
			private Aspekte(final String name, final String pid) {
				this.name = name;
				this.pid = pid;
			}
	
			@Override
			public String getName() {
				if (getSystemObject() == null) {
					return name;
				}
				return super.getName();
			}
	
			@Override
			public String getPid() {
				if (getSystemObject() == null) {
					return pid;
				}
				return super.getPid();
			}
			
			@Override
			public Aspect getSystemObject() {
				return (Aspect) super.getSystemObject();
			}
	
			@Override
			public String toString() {
				if (getSystemObject() == null) {
					return name + " (" + pid + ")";
				}
				return super.toString();
			}
	
		}
	
	/**
	 * Kapselt die Daten des Datensatzes.
	 */
	public static class Daten extends AbstractDatum implements KonfigurationsDatum {
		
		/**
		 * Initialisiert das Datum.
		 * 
		 * @param datensatz
		 *            der Datensatz zu dem das Datum gehört.
		 * @param aspekt
		 *            der Aspekt für das Datum.
		 */
		public Daten(final Datensatz datensatz, final Aspekt aspekt) {
			super(datensatz, aspekt);
		}
		
		
			/*
			 * Beginn Propertiesabschnitt
			 */
		
				private de.bsvrz.sys.funclib.bitctrl.modell.ilse.attribute.AttSchaltSequenz
				 _sequenz
				;
				private 	RelativerZeitstempel
				 _halteZeit
				;
		
			/**
			Attribut zum Schalten von einem Zustand in einen anderen.
			<p>
			
			</p>
			
			@return der Wert von Sequenz.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.ilse.attribute.AttSchaltSequenz
				 getSequenz() {
				return _sequenz;
			}
		
			/**
			Attribut zum Schalten von einem Zustand in einen anderen.
			<p>
			
			</p>
			
			@param _sequenz der neue Wert von Sequenz.
			*/
			public void setSequenz(de.bsvrz.sys.funclib.bitctrl.modell.ilse.attribute.AttSchaltSequenz
			 _sequenz) {
				this._sequenz = _sequenz;
			}
		
			/**
			Angabe einer Zeitdauer.
			<p>
			
			</p>
			
			@return der Wert von HalteZeit.
			*/
				public 	RelativerZeitstempel
				 getHalteZeit() {
				return _halteZeit;
			}
		
			/**
			Angabe einer Zeitdauer.
			<p>
			
			</p>
			
			@param _halteZeit der neue Wert von HalteZeit.
			*/
			public void setHalteZeit(	RelativerZeitstempel
			 _halteZeit) {
				this._halteZeit = _halteZeit;
			}
		
		
			/*
			 * Ende Propertiesabschnitt
			 */
		
			/*
			 * Beginn Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			public void bean2Atl(final Data datum, final ObjektFactory factory) {
					// GanzzahlAttributTyp
					if (getSequenz() != null) {
		                if (getSequenz().isZustand()) {
		                    datum.getUnscaledValue("Sequenz").setText(getSequenz().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("Sequenz").set(getSequenz().getValue());
		                }
					}
					// ZeitstempelAttributTyp
						datum.getTimeValue("HalteZeit").setMillis(getHalteZeit().getTime());
			}
		
			public void atl2Bean(final Data daten, final ObjektFactory factory) {
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("Sequenz").isState()) {
								setSequenz(de.bsvrz.sys.funclib.bitctrl.modell.ilse.attribute.AttSchaltSequenz
								.getZustand(daten.getScaledValue("Sequenz").getText()));
							} else {
							setSequenz(new de.bsvrz.sys.funclib.bitctrl.modell.ilse.attribute.AttSchaltSequenz
							(daten.
								getUnscaledValue
							("Sequenz").
									byteValue
							()));
							}
					// ZeitstempelAttributTyp
						setHalteZeit(new
							RelativerZeitstempel
							(daten.getTimeValue("HalteZeit").getMillis()));
			}
		
			/*
			 * Ende Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			
		@Override
		public Daten clone() {
			final Daten klon = new Daten(dGetDatensatz(), dGetAspekt());
	
							klon.setSequenz(getSequenz());
							klon.setHalteZeit(getHalteZeit());
			
	
			return klon;
		}

		@Override
		public String toString() {
			return BeanUtils.toString(this);
		}
	
	}
	
		/** Die PID der Attributgruppe im Datenverteiler. */
		public static final String PID = "atg.steuerungExterneIO";

	/**
	 * Initialisiert den Konfigurationsdatensatz.
	 * 
	 * @param systemObjekt
	 *            das Systemobjekt zu dem der Datensatz gehört.
	 * @param objektFactory
	 *            die ObjektFabrik, die der Datensatz verwenden soll.
	 */
	public KdSteuerungExterneIO(final SystemObjekt systemObjekt,
			final ObjektFactory objektFactory) {
		super(systemObjekt, objektFactory);
	}

	
		@Override
		public void init(final SystemObject systemObject,
				final ObjektFactory objektFactory) {
			super.init(systemObject, objektFactory);
			for (final Aspekt asp : Aspekte.values()) {
				((AbstractSystemObjekt) asp).init(objektFactory.getModellobjekt(asp.getPid()).getSystemObject(), objektFactory);
			}
		}
		
		@Override
		protected String doGetPid() {
			return PID;
		}
	
		public Collection<? extends Aspekt> getAspekte() {
			return Arrays.asList(Aspekte.values());
		}
	
		public Daten createDatum() {
			Daten datum = new Daten(this, null);
			// TODO Auslesen der Defaultwerte geht nicht,
			// weil der Datenverteiler für Attribute ohne Defaultwert initial ungültige Werte setzt!!
			// datum.atl2Bean(createSendeCache(), getObjektFactory());
			return datum;
		}
		 
	
}
