/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Legt die Rolle(Sender, Senke, Empfänger, Quelle) einer Anmeldung fest.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 6
 */
public class AttRolleAnmeldung extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	Es soll als Quelle angemeldet werden.
	<p>
	
	</p>
	*/
	public static final AttRolleAnmeldung ZUSTAND_1_QUELLE = new AttRolleAnmeldung("Quelle", 		Byte
	.valueOf("1"));

	/**
	Es soll als Sender angemeldet werden.
	<p>
	
	</p>
	*/
	public static final AttRolleAnmeldung ZUSTAND_2_SENDER = new AttRolleAnmeldung("Sender", 		Byte
	.valueOf("2"));

	/**
	Es soll als Senke angemeldet werden.
	<p>
	
	</p>
	*/
	public static final AttRolleAnmeldung ZUSTAND_3_SENKE = new AttRolleAnmeldung("Senke", 		Byte
	.valueOf("3"));

	/**
	Es soll als Empfänger angemeldet werden.
	<p>
	
	</p>
	*/
	public static final AttRolleAnmeldung ZUSTAND_4_EMPFAENGER = new AttRolleAnmeldung("Empfänger", 		Byte
	.valueOf("4"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttRolleAnmeldung getZustand(final 		Byte
	 value) {
		for (AttRolleAnmeldung e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttRolleAnmeldung getZustand(final String value) {
		for (AttRolleAnmeldung e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttRolleAnmeldung> getZustaende() {
		List<AttRolleAnmeldung> list = new ArrayList<AttRolleAnmeldung>();
		list.add(ZUSTAND_1_QUELLE);
		list.add(ZUSTAND_2_SENDER);
		list.add(ZUSTAND_3_SENKE);
		list.add(ZUSTAND_4_EMPFAENGER);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut RolleAnmeldung.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttRolleAnmeldung(final 		Byte
	 value) {
		super(value);
	}
	
	private AttRolleAnmeldung(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
