/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Gefriertemperatur.
<p>
&lt;absatz&gt;
						Die Gefriertemperatur ist diejenige Temperatur
						in Grad Celsius, bei der die an der Oberfläche
						der Sonde vorhandene wässrige Taumittel-Lösung
						gefrieren (Übergang in den festen
						Aggregatszustand) könnte. Es wird der IST-Wert
						übertragen.
					&lt;&#47;absatz&gt;
					&lt;absatz&gt;
						0 °C Keine Gefriertemperatur-Erniedrigung bzw.
						keine Taumittelkonzentration messbar bzw. die
						Bedingungen lassen eine Bestimmung nicht zu.
						Wenn gleichzeitig auch ?Salzrest? (DE-Typ 52)
						übertragen wird ist auch dieser Wert zu
						betrachten (255 = nicht messbar).
					&lt;&#47;absatz&gt;
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 19
 */
@Wertebereich(
	minimum = -32768L,
	maximum = 32767L,
	skalierung = 0.1,
	einheit = "°C"
)
@Defaultwert(wert = "nicht ermittelbar")
public class AttTlsUfdGefriertemperatur extends Zahl<		Double
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MIN_VALUE =
			(		double
			) (		Double
			.valueOf("-32768") * 		Double
			.valueOf("0.1"));	
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MAX_VALUE =
			(		double
			) (		Double
			.valueOf("32767") * 		Double
			.valueOf("0.1"));	
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "°C";
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsUfdGefriertemperatur ZUSTAND_32767_NICHT_ERMITTELBAR = new AttTlsUfdGefriertemperatur("nicht ermittelbar", 		Double
	.valueOf("32767"));

	/**
	Gefriertemperatur-Erniedrigung bzw. keine
								Taumittelkonzentration nicht messbar.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdGefriertemperatur ZUSTAND_0_GEFRIERPUNKT_NICHT_ERMITTELBAR = new AttTlsUfdGefriertemperatur("Gefrierpunkt nicht ermittelbar", 		Double
	.valueOf("0"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsUfdGefriertemperatur getZustand(final 		Double
	 value) {
		for (AttTlsUfdGefriertemperatur e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsUfdGefriertemperatur getZustand(final String value) {
		for (AttTlsUfdGefriertemperatur e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsUfdGefriertemperatur> getZustaende() {
		List<AttTlsUfdGefriertemperatur> list = new ArrayList<AttTlsUfdGefriertemperatur>();
		list.add(ZUSTAND_32767_NICHT_ERMITTELBAR);
		list.add(ZUSTAND_0_GEFRIERPUNKT_NICHT_ERMITTELBAR);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TLSUfdGefriertemperatur.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsUfdGefriertemperatur(final 		Double
	 value) {
		super(value);
	}
	
	private AttTlsUfdGefriertemperatur(final String zustand, final 		Double
	 value) {
		super(zustand, value);
	}
	
}
