/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.parameter;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Parameter für die Helligkeitssteuerung.
<p>
&lt;absatz&gt;
						Zuordnung von Helligkeitswerten (Prozent) zu Helligkeitsstufen für die Helligkeitssteuerung.
            Helligkeitsstufe entspricht Index + 1.		
					&lt;&#47;absatz&gt;
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 18
 */
public class PdHelligkeitSteuerungStufe extends AbstractParameterDatensatz<PdHelligkeitSteuerungStufe.Daten> {

		/**
		 * Die vorhandenen Aspekte des Datensatzes.
		 */
		public static class Aspekte extends de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.objekte.impl.AspektImpl implements Aspekt {
	
			public static Aspekt[] values() {
				return new Aspekt[] {
					Aspekte.ParameterDefault,
					Aspekte.ParameterSoll,
					Aspekte.ParameterVorgabe,
					Aspekte.ParameterIst,
				};
			}
	
			/**
			 * Aspekt der zur Versorgung von Defaultwerten für Parameter verwendet werden kann.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterDefault = new Aspekte("Default-Parameter-Aspekt", "asp.parameterDefault");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterSoll = new Aspekte("Soll-Parameter-Aspekt", "asp.parameterSoll");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterVorgabe = new Aspekte("Vorgabe-Parameter-Aspekt", "asp.parameterVorgabe");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterIst = new Aspekte("Ist-Parameter-Aspekt", "asp.parameterIst");
			
			;
			
			private final String name;
			private final String pid;
	
			private Aspekte(final String name, final String pid) {
				this.name = name;
				this.pid = pid;
			}
	
			@Override
			public String getName() {
				if (getSystemObject() == null) {
					return name;
				}
				return super.getName();
			}
	
			@Override
			public String getPid() {
				if (getSystemObject() == null) {
					return pid;
				}
				return super.getPid();
			}
			
			@Override
			public Aspect getSystemObject() {
				return (Aspect) super.getSystemObject();
			}
	
			@Override
			public String toString() {
				if (getSystemObject() == null) {
					return name + " (" + pid + ")";
				}
				return super.toString();
			}
	
		}
	
	/**
	 * Kapselt die Daten des Datensatzes.
	 */
	public static class Daten extends AbstractOnlineDatum {
		
		/**
		 * Initialisiert das Onlinedatum.
		 * 
		 * @param datensatz
		 *            der Datensatz zu dem das Datum gehört.
		 * @param aspekt
		 *            der Aspekt für das Datum.
		 */
		public Daten(final Datensatz datensatz, final Aspekt aspekt) {
			super(datensatz, aspekt);
		}
		
		
			/*
			 * Beginn Propertiesabschnitt
			 */
		
				private Feld<de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttProzent
				> _stufen = new Feld<de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttProzent
				>(0, true);
				private 	RelativerZeitstempel
				 _standzeit
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.attribute.AttHelligkeitSteuerung
				 _steuerung
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 _urlasser
				= new de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				()
				;
		
			/**
			Helligkeitswert (Prozent) der Stufe.
			<p>
			
			</p>
			
			@return der Wert von Stufen.
			*/
				public Feld<de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttProzent
				> getStufen() {
				return _stufen;
			}
		
		
			/**
			Mindesstandzeit für die Helligkeitsänderung.
			<p>
			
			</p>
			
			@return der Wert von Standzeit.
			*/
				public 	RelativerZeitstempel
				 getStandzeit() {
				return _standzeit;
			}
		
			/**
			Mindesstandzeit für die Helligkeitsänderung.
			<p>
			
			</p>
			
			@param _standzeit der neue Wert von Standzeit.
			*/
			public void setStandzeit(	RelativerZeitstempel
			 _standzeit) {
				this._standzeit = _standzeit;
			}
		
			/**
			Art der Helligkeitssteuerung.
			            lokal = Helligkeitssteuerung Vorort, "über Stufe" = Helligkeitssteuerung über die ermittelte Stufe.
			<p>
			
			</p>
			
			@return der Wert von Steuerung.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.attribute.AttHelligkeitSteuerung
				 getSteuerung() {
				return _steuerung;
			}
		
			/**
			Art der Helligkeitssteuerung.
			            lokal = Helligkeitssteuerung Vorort, "über Stufe" = Helligkeitssteuerung über die ermittelte Stufe.
			<p>
			
			</p>
			
			@param _steuerung der neue Wert von Steuerung.
			*/
			public void setSteuerung(de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.attribute.AttHelligkeitSteuerung
			 _steuerung) {
				this._steuerung = _steuerung;
			}
		
			/**
			Urlasser Informationen.
			<p>
			
			</p>
			
			@return der Wert von Urlasser.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 getUrlasser() {
				return _urlasser;
			}
		
			/**
			Urlasser Informationen.
			<p>
			
			</p>
			
			@param _urlasser der neue Wert von Urlasser.
			*/
			public void setUrlasser(de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
			 _urlasser) {
				this._urlasser = _urlasser;
			}
		
		
			/*
			 * Ende Propertiesabschnitt
			 */
		
			/*
			 * Beginn Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			public void bean2Atl(final Data datum, final ObjektFactory factory) {
					// GanzzahlAttributTyp
					if (getStufen() != null) {
						final Data.NumberArray arrayStufen = datum.
							getUnscaledArray
							("Stufen");
						arrayStufen.setLength(getStufen().size());
						for (int i = 0; i < arrayStufen.getLength(); ++i) {
							arrayStufen.getValue(i).set(getStufen().get(i).getValue());
						}
					}
					// ZeitstempelAttributTyp
						datum.getTimeValue("Standzeit").setMillis(getStandzeit().getTime());
					// GanzzahlAttributTyp
					if (getSteuerung() != null) {
		                if (getSteuerung().isZustand()) {
		                    datum.getUnscaledValue("Steuerung").setText(getSteuerung().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("Steuerung").set(getSteuerung().getValue());
		                }
					}
					// AttributListenDefinition
						getUrlasser().bean2Atl(datum.getItem("Urlasser"), factory);
			}
		
			public void atl2Bean(final Data daten, final ObjektFactory factory) {
					// GanzzahlAttributTyp
						final Data.NumberArray arrayStufen = daten.
							getUnscaledArray
						("Stufen");
		
						for (int i = 0; i < arrayStufen.getLength(); ++i) {
		                    if (arrayStufen.getValue(i).isState()) {
		                        getStufen().add(de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttProzent
		                        .getZustand(arrayStufen.getValue(i).getState().getName()));
		                    } else {
		                    getStufen().add(new de.bsvrz.sys.funclib.bitctrl.modell.fachmodellglobal.attribute.AttProzent
		                    (arrayStufen.
		                    		byteValue
		                    (i)));
		                    }
		                }
					// ZeitstempelAttributTyp
						setStandzeit(new
							RelativerZeitstempel
							(daten.getTimeValue("Standzeit").getMillis()));
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("Steuerung").isState()) {
								setSteuerung(de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.attribute.AttHelligkeitSteuerung
								.getZustand(daten.getScaledValue("Steuerung").getText()));
							} else {
							setSteuerung(new de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.attribute.AttHelligkeitSteuerung
							(daten.
								getUnscaledValue
							("Steuerung").
									byteValue
							()));
							}
					// AttributListenDefinition
						getUrlasser().atl2Bean(daten.getItem("Urlasser"), factory);
			}
		
			/*
			 * Ende Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			
		@Override
		public Daten clone() {
			final Daten klon = new Daten(dGetDatensatz(), dGetAspekt());
	
						klon._stufen = getStufen().clone();
							klon.setStandzeit(getStandzeit());
							klon.setSteuerung(getSteuerung());
							klon._urlasser = getUrlasser().clone();
			
			
			klon.dSetZeitstempel(dGetZeitstempel());
			klon.dSetDatenStatus(dGetDatenStatus());
	
			return klon;
		}

		@Override
		public String toString() {
			return BeanUtils.toString(this);
		}
	
	}

		/** Die PID der Attributgruppe im Datenverteiler. */
		public static final String PID = "atg.helligkeitSteuerungStufe";

	/**
	 * Initialisiert den Parameterdatensatz.
	 * 
	 * @param systemObjekt
	 *            das Systemobjekt zu dem der Datensatz gehört.
	 * @param objektFactory
	 *            die ObjektFabrik, die der Datensatz verwenden soll.
	 */
	public PdHelligkeitSteuerungStufe(final SystemObjekt systemObjekt,
			final ObjektFactory objektFactory) {
		super(systemObjekt, objektFactory);
	}

	
		@Override
		public void init(final SystemObject systemObject,
				final ObjektFactory objektFactory) {
			super.init(systemObject, objektFactory);
			for (final Aspekt asp : Aspekte.values()) {
				((AbstractSystemObjekt) asp).init(objektFactory.getModellobjekt(asp.getPid()).getSystemObject(), objektFactory);
			}
		}
		
		@Override
		protected String doGetPid() {
			return PID;
		}
	
		public Collection<? extends Aspekt> getAspekte() {
			return Arrays.asList(Aspekte.values());
		}
	
		public Daten createDatum() {
			Daten datum = new Daten(this, null);
			// TODO Auslesen der Defaultwerte geht nicht,
			// weil der Datenverteiler für Attribute ohne Defaultwert initial ungültige Werte setzt!!
			// datum.atl2Bean(createSendeCache(), getObjektFactory());
			return datum;
		}
		 

}
