/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmvewudaglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
die Art der Ausführungs (des Starts) eines Uda-Skript-Laufs.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttUdaStartTyp extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	Skriptlauf wird sofort ausgeführt, wenn das Skript freigegeben ist.
	<p>
	
	</p>
	*/
	public static final AttUdaStartTyp ZUSTAND_1_SOFORT = new AttUdaStartTyp("sofort", 		Byte
	.valueOf("1"));

	/**
	der Skriptlauf wird ausgeführt, wenn eine entsprechende Anforderung durch einen Nutzer
								erfolgt ist.
	<p>
	
	</p>
	*/
	public static final AttUdaStartTyp ZUSTAND_2_EXPLIZIT = new AttUdaStartTyp("explizit", 		Byte
	.valueOf("2"));

	/**
	das Skript wird zyklisch ausgeführt.
	<p>
	
	</p>
	*/
	public static final AttUdaStartTyp ZUSTAND_3_ZYKLISCH = new AttUdaStartTyp("zyklisch", 		Byte
	.valueOf("3"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttUdaStartTyp getZustand(final 		Byte
	 value) {
		for (AttUdaStartTyp e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttUdaStartTyp getZustand(final String value) {
		for (AttUdaStartTyp e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttUdaStartTyp> getZustaende() {
		List<AttUdaStartTyp> list = new ArrayList<AttUdaStartTyp>();
		list.add(ZUSTAND_1_SOFORT);
		list.add(ZUSTAND_2_EXPLIZIT);
		list.add(ZUSTAND_3_ZYKLISCH);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut UdaStartTyp.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttUdaStartTyp(final 		Byte
	 value) {
		super(value);
	}
	
	private AttUdaStartTyp(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
